import { __decorate, __metadata, __param } from "tslib";
import Aurelia, { CustomAttribute, IAurelia } from 'aurelia';
import { strings } from '@material/dialog';
import { CustomElement } from '@aurelia/runtime-html';
/** Service to open MDC dialogs */
let MdcDialogService = class MdcDialogService {
    au;
    constructor(au) {
        this.au = au;
    }
    /** Opens the dialog specified in the options */
    async open(options) {
        let closedResolver;
        const closedPromise = new Promise(r => closedResolver = r);
        let openedResolver;
        const openedPromise = new Promise(r => openedResolver = r);
        const bindingContext = {
            handleClosed: (evt) => {
                closedResolver(evt.detail.action);
                controller.deactivate(controller, null);
                dialogVm.root.removeEventListener(strings.CLOSED_EVENT, bindingContext.handleClosed);
                dialogVm.root.removeEventListener(strings.OPENED_EVENT, bindingContext.handleOpened);
                dialogContainer.remove();
            },
            handleOpened: () => {
                openedResolver();
            }
        };
        const dialogContainer = document.createElement('div');
        const def = CustomElement.getDefinition(options.viewModel);
        dialogContainer.innerHTML = `<${def.name}></${def.name}>`;
        document.body.appendChild(dialogContainer);
        const controller = await this.au.enhance({ host: dialogContainer, component: {} });
        const dialogVm = CustomElement.for(dialogContainer.querySelector('mdc-dialog')).viewModel;
        dialogVm.root.addEventListener(strings.CLOSED_EVENT, bindingContext.handleClosed);
        dialogVm.root.addEventListener(strings.OPENED_EVENT, bindingContext.handleOpened);
        const vm = CustomElement.for(dialogContainer.firstChild).viewModel;
        if (vm.loading) {
            const loadingResult = vm.loading(options.model);
            if (loadingResult instanceof Promise) {
                await loadingResult;
            }
        }
        await dialogVm.initialised;
        dialogVm.open();
        await openedPromise;
        // re-layout ripple elements because dialogs use `transform: scale(.8)` and initial layout is incorrect
        const ripples = Array.from(dialogVm.root.querySelectorAll('.mdc-ripple-upgraded'));
        await Promise.all(ripples.map(async (x) => {
            const ripple = CustomAttribute.for(x, 'mdc-ripple');
            await ripple?.viewModel.initialised;
            ripple?.viewModel.foundation?.layout();
        }));
        return await closedPromise;
    }
};
MdcDialogService = __decorate([
    __param(0, IAurelia),
    __metadata("design:paramtypes", [Aurelia])
], MdcDialogService);
export { MdcDialogService };
//# sourceMappingURL=mdc-dialog-service.js.map